# Introduction to usito

This package is provided by researchers of the *Institute of Applied Optics (University of Stuttgart)*. It enables students and fellow researchers a simple introduction into *neural networks* and allows the generic use of those networks. The package shall also grow over time, that we can provide more sophisticated architectures and modified class methods (e.g. for layers or activation functions). 

Our development is (at least currently) solely based on the keras and tensorflow engine.

Participation is welcomed.

**Welcome to the ITO family.**
**Plug in and play :)**

Your developers and maintainers,
AliB and FelixFischer

# How to get started
```python
#importing the package 
import usito

#loading example
data = usito.load('./test.csv', header = 0)
```

## ToDos:
- [x] Data import and export
- [x] Zipping and unzipping option
- [ ] Creating pip package for usito